==> nmdc_runtime-1.0.6.tar.gz: nmdc_runtime-1.0.6/tests/integration/test_minter_repository.py <==
import collections

from nmdc_runtime.minter.adapters.repository import InMemoryIDStore, MongoIDStore
from nmdc_runtime.minter.domain.model import (
    ResolutionRequest,
    Identifier,
    DeleteRequest,
)
from tests.conftest import minting_request, get_mongo_test_db, get_test_inmemoryidstore


def test_mint_one():
    s: InMemoryIDStore = get_test_inmemoryidstore()
    req_mint = minting_request()
    assert req_mint.how_many == 1
    ids = s.mint(req_mint)
    assert len(ids) == 1


def test_mint_many():
    s: InMemoryIDStore = get_test_inmemoryidstore()
    req_mint = minting_request()
    req_mint.how_many = 1_000
    ids = s.mint(req_mint)
    assert len(ids) == 1_000


def test_mint_and_resolve():
    s: InMemoryIDStore = get_test_inmemoryidstore()
    req_mint = minting_request()
    id_: Identifier = next(i for i in s.mint(req_mint))
    req_res = ResolutionRequest(
        id_name=id_.name,
        **req_mint.model_dump(
            mode="json",
        ),
    )
    assert s.resolve(req_res) is not None


def test_mint_and_delete():
    s: InMemoryIDStore = get_test_inmemoryidstore()
    req_mint = minting_request()
    id_: Identifier = next(i for i in s.mint(req_mint))
    req_del = DeleteRequest(
        id_name=id_.name,
        **req_mint.model_dump(
            mode="json",
        ),
    )
    s.delete(req_del)
    assert (
        s.resolve(
            ResolutionRequest(
                **req_del.model_dump(
                    mode="json",
                )
            )
        )
        is None
    )


def test_mongo_mint_one():
    s = MongoIDStore(get_mongo_test_db())
    s.db["minter.id_records"].drop()

    req_mint = minting_request()
    assert req_mint.how_many == 1
    ids = s.mint(req_mint)
    assert len(ids) == 1
    assert s.db["minter.id_records"].count_documents({}) == 1


def test_mongo_mint_many():
    s = MongoIDStore(get_mongo_test_db())
    s.db["minter.id_records"].drop()

    req_mint = minting_request()
    req_mint.how_many = 1_000
    ids = s.mint(req_mint)
    assert len(ids) == 1_000
    assert s.db["minter.id_records"].count_documents({}) == 1_000


def test_mongo_mint_and_resolve():
    s = MongoIDStore(get_mongo_test_db())
    s.db["minter.id_records"].drop()

    req_mint = minting_request()
    id_: Identifier = next(i for i in s.mint(req_mint))
    req_res = ResolutionRequest(
        id_name=id_.name,
        **req_mint.model_dump(
            mode="json",
        ),
    )
    assert s.resolve(req_res) is not None


def test_mongo_mint_and_delete():
    s = MongoIDStore(get_mongo_test_db())
    s.db["minter.id_records"].drop()

    req_mint = minting_request()
    id_: Identifier = next(i for i in s.mint(req_mint))
    req_del = DeleteRequest(
        id_name=id_.name,
        **req_mint.model_dump(
            mode="json",
        ),
    )
    s.delete(req_del)
    assert (
        s.resolve(
            ResolutionRequest(
                **req_del.model_dump(
                    mode="json",
                )
            )
        )
        is None
    )
    assert s.db["minter.id_records"].count_documents({}) == 0

==> nmdc_runtime-1.0.14.tar.gz: nmdc_runtime-1.0.14/tests/integration/test_minter_repository.py <==
import collections

from nmdc_runtime.minter.adapters.repository import InMemoryIDStore, MongoIDStore
from nmdc_runtime.minter.domain.model import (
    ResolutionRequest,
    Identifier,
    DeleteRequest,
)
from tests.conftest import minting_request, get_mongo_test_db, get_test_inmemoryidstore


def test_mint_one():
    s: InMemoryIDStore = get_test_inmemoryidstore()
    req_mint = minting_request()
    assert req_mint.how_many == 1
    ids = s.mint(req_mint)
    assert len(ids) == 1


def test_mint_many():
    s: InMemoryIDStore = get_test_inmemoryidstore()
    req_mint = minting_request()
    req_mint.how_many = 1_000
    ids = s.mint(req_mint)
    assert len(ids) == 1_000


def test_mint_and_resolve():
    s: InMemoryIDStore = get_test_inmemoryidstore()
    req_mint = minting_request()
    id_: Identifier = next(i for i in s.mint(req_mint))
    req_res = ResolutionRequest(
        id_name=id_.name,
        **req_mint.model_dump(),
    )
    assert s.resolve(req_res) is not None


def test_mint_and_delete():
    s: InMemoryIDStore = get_test_inmemoryidstore()
    req_mint = minting_request()
    id_: Identifier = next(i for i in s.mint(req_mint))
    req_del = DeleteRequest(
        id_name=id_.name,
        **req_mint.model_dump(),
    )
    s.delete(req_del)
    assert s.resolve(ResolutionRequest(**req_del.model_dump())) is None


def test_mongo_mint_one():
    s = MongoIDStore(get_mongo_test_db())
    s.db["minter.id_records"].drop()

    req_mint = minting_request()
    assert req_mint.how_many == 1
    ids = s.mint(req_mint)
    assert len(ids) == 1
    assert s.db["minter.id_records"].count_documents({}) == 1


def test_mongo_mint_many():
    s = MongoIDStore(get_mongo_test_db())
    s.db["minter.id_records"].drop()

    req_mint = minting_request()
    req_mint.how_many = 1_000
    ids = s.mint(req_mint)
    assert len(ids) == 1_000
    assert s.db["minter.id_records"].count_documents({}) == 1_000


def test_mongo_mint_and_resolve():
    s = MongoIDStore(get_mongo_test_db())
    s.db["minter.id_records"].drop()

    req_mint = minting_request()
    id_: Identifier = next(i for i in s.mint(req_mint))
    req_res = ResolutionRequest(
        id_name=id_.name,
        **req_mint.model_dump(),
    )
    assert s.resolve(req_res) is not None


def test_mongo_mint_and_delete():
    s = MongoIDStore(get_mongo_test_db())
    s.db["minter.id_records"].drop()

    req_mint = minting_request()
    id_: Identifier = next(i for i in s.mint(req_mint))
    req_del = DeleteRequest(
        id_name=id_.name,
        **req_mint.model_dump(),
    )
    s.delete(req_del)
    assert s.resolve(ResolutionRequest(**req_del.model_dump())) is None
    assert s.db["minter.id_records"].count_documents({}) == 0
